@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-languages-manager.c,v 1.13 2006/08/23 15:21:27 paolo Exp $
+ * $Id: gedit-languages-manager.c 5407 2007-01-04 13:30:58Z pborelli $
  */
 
 /* FIXME: Monitor gconf keys */
@@ -110,15 +110,6 @@ get_gconf_key (GtkSourceLanguage *language, const gchar *tag_id)
 	return key;
 }
 
-static gchar * 
-gdk_color_to_string (GdkColor color)
-{
-	return g_strdup_printf ("#%04x%04x%04x",
-				color.red, 
-				color.green,
-				color.blue);
-}
-
 static gchar *
 tag_style_to_string (const GtkSourceTagStyle *style)
 {
@@ -126,8 +117,8 @@ tag_style_to_string (const GtkSourceTagStyle *style)
 	gchar *background;
 	gchar *foreground;
 
-	background = gdk_color_to_string (style->background);
-	foreground = gdk_color_to_string (style->foreground);
+	background = gedit_gdk_color_to_string (style->background);
+	foreground = gedit_gdk_color_to_string (style->foreground);
 
 	res = g_strdup_printf ("%d/%s/%s/%d/%d/%d/%d",
 			style->mask,
