@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-prefs-manager-app.c,v 1.17 2006/10/08 14:26:02 pborelli Exp $
+ * $Id: gedit-prefs-manager-app.c 5451 2007-01-20 15:31:11Z paolo $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,41 +47,46 @@
 #include "gedit-window-private.h"
 
 static void gedit_prefs_manager_editor_font_changed	(GConfClient *client,
-		   				 	 guint        cnxn_id,
-			   				 GConfEntry  *entry,
-			   				 gpointer     user_data);
+							 guint        cnxn_id,
+							 GConfEntry  *entry,
+							 gpointer     user_data);
 
-static void gedit_prefs_manager_editor_colors_changed 	(GConfClient *client,
-			   				 guint        cnxn_id,
-			   				 GConfEntry  *entry,
-			   				 gpointer     user_data);
+static void gedit_prefs_manager_system_font_changed	(GConfClient *client,
+							 guint        cnxn_id,
+							 GConfEntry  *entry,
+							 gpointer     user_data);
 
-static void gedit_prefs_manager_tabs_size_changed 	(GConfClient *client,
-						       	 guint        cnxn_id, 
-						       	 GConfEntry  *entry, 
-						       	 gpointer     user_data);
-				       	 
-static void gedit_prefs_manager_wrap_mode_changed 	(GConfClient *client,
+static void gedit_prefs_manager_editor_colors_changed	(GConfClient *client,
+							 guint        cnxn_id,
+							 GConfEntry  *entry,
+							 gpointer     user_data);
+
+static void gedit_prefs_manager_tabs_size_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
 
-static void gedit_prefs_manager_line_numbers_changed 	(GConfClient *client,
+static void gedit_prefs_manager_wrap_mode_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
 
-static void gedit_prefs_manager_auto_indent_changed 	(GConfClient *client,
+static void gedit_prefs_manager_line_numbers_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
 
-static void gedit_prefs_manager_undo_changed 		(GConfClient *client,
+static void gedit_prefs_manager_auto_indent_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
 
-static void gedit_prefs_manager_right_margin_changed 	(GConfClient *client,
+static void gedit_prefs_manager_undo_changed		(GConfClient *client,
+							 guint        cnxn_id, 
+							 GConfEntry  *entry, 
+							 gpointer     user_data);
+
+static void gedit_prefs_manager_right_margin_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
@@ -107,7 +112,7 @@ static void gedit_prefs_manager_search_hl_enable_changed(GConfClient *client,
 							 gpointer     user_data);
 
 
-static void gedit_prefs_manager_max_recents_changed 	(GConfClient *client,
+static void gedit_prefs_manager_max_recents_changed	(GConfClient *client,
 							 guint        cnxn_id, 
 							 GConfEntry  *entry, 
 							 gpointer     user_data);
@@ -117,7 +122,7 @@ static void gedit_prefs_manager_auto_save_changed	(GConfClient *client,
 							 GConfEntry  *entry,
 							 gpointer     user_data);
 
-static void gedit_prefs_manager_lockdown_changed 	(GConfClient *client,
+static void gedit_prefs_manager_lockdown_changed	(GConfClient *client,
 							 guint        cnxn_id,
 							 GConfEntry  *entry,
 							 gpointer     user_data);
@@ -132,6 +137,8 @@ static gint bottom_panel_size = -1;
 static gint side_panel_active_page = 0;
 static gint bottom_panel_active_page = 0;
 
+static gint active_file_filter = -1;
+
 gboolean
 gedit_prefs_manager_app_init (void)
 {
@@ -159,6 +166,11 @@ gedit_prefs_manager_app_init (void)
 				gedit_prefs_manager_editor_font_changed,
 				NULL, NULL, NULL);
 
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_SYSTEM_FONT,
+				gedit_prefs_manager_system_font_changed,
+				NULL, NULL, NULL);
+
 		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
 				GPM_COLORS_DIR,
 				gedit_prefs_manager_editor_colors_changed,
@@ -432,6 +444,33 @@ gedit_prefs_manager_bottom_panel_active_page_can_set (void)
 	return TRUE;
 }
 
+/* File filter */
+gint
+gedit_prefs_manager_get_active_file_filter (void)
+{
+	if (active_file_filter == -1)
+		active_file_filter = gnome_config_get_int (GPM_ACTIVE_FILE_FILTER "=0");
+
+	return active_file_filter;
+}
+
+void
+gedit_prefs_manager_set_active_file_filter (gint id)
+{
+	g_return_if_fail (id >= 0);
+	
+	if (active_file_filter == id)
+		return;
+
+	active_file_filter = id;
+	gnome_config_set_int (GPM_ACTIVE_FILE_FILTER, id);
+}
+
+gboolean 
+gedit_prefs_manager_active_file_filter_can_set (void)
+{
+	return TRUE;
+}
 static void 
 gedit_prefs_manager_editor_font_changed (GConfClient *client,
 					 guint        cnxn_id, 
@@ -456,10 +495,12 @@ gedit_prefs_manager_editor_font_changed (GConfClient *client,
 		else
 			def = GPM_DEFAULT_USE_DEFAULT_FONT;
 		
-		font = NULL;
+		if (def)
+			font = gedit_prefs_manager_get_system_font ();
+		else
+			font = gedit_prefs_manager_get_editor_font ();
 	}
-	else
-	if (strcmp (entry->key, GPM_EDITOR_FONT) == 0)
+	else if (strcmp (entry->key, GPM_EDITOR_FONT) == 0)
 	{
 		if (entry->value->type == GCONF_VALUE_STRING)
 			font = g_strdup (gconf_value_get_string (entry->value));
@@ -471,8 +512,52 @@ gedit_prefs_manager_editor_font_changed (GConfClient *client,
 	else
 		return;
 
-	if ((font == NULL) && !def)
-		font = gedit_prefs_manager_get_editor_font ();
+	g_return_if_fail (font != NULL);
+	
+	ts = gedit_prefs_manager_get_tabs_size ();
+
+	views = gedit_app_get_views (gedit_app_get_default ());
+	l = views;
+
+	while (l != NULL)
+	{
+		/* Note: we use def=FALSE to avoid GeditView to query gconf */
+		gedit_view_set_font (GEDIT_VIEW (l->data), FALSE,  font);
+		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data), ts);
+
+		l = l->next;
+	}
+
+	g_list_free (views);
+	g_free (font);
+}
+
+static void 
+gedit_prefs_manager_system_font_changed (GConfClient *client,
+					 guint        cnxn_id, 
+					 GConfEntry  *entry, 
+					 gpointer     user_data)
+{
+	GList *views;
+	GList *l;
+	gchar *font;
+	gint ts;
+
+	gedit_debug (DEBUG_PREFS);
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_SYSTEM_FONT) != 0)
+		return;
+
+	if (!gedit_prefs_manager_get_use_default_font ())
+		return;
+
+	if (entry->value->type == GCONF_VALUE_STRING)
+		font = g_strdup (gconf_value_get_string (entry->value));
+	else
+		font = g_strdup (GPM_DEFAULT_SYSTEM_FONT);
 
 	ts = gedit_prefs_manager_get_tabs_size ();
 
@@ -481,12 +566,10 @@ gedit_prefs_manager_editor_font_changed (GConfClient *client,
 
 	while (l != NULL)
 	{
-		gedit_view_set_font (GEDIT_VIEW (l->data),
-				     def, 
-				     font);
-		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data),
-						ts);
+		/* Note: we use def=FALSE to avoid GeditView to query gconf */
+		gedit_view_set_font (GEDIT_VIEW (l->data), FALSE, font);
 
+		gtk_source_view_set_tabs_width (GTK_SOURCE_VIEW (l->data), ts);
 		l = l->next;
 	}
 
@@ -1092,7 +1175,7 @@ gedit_prefs_manager_search_hl_enable_changed (GConfClient *client,
 			g_return_if_fail (GEDIT_IS_DOCUMENT (l->data));
 
 			gedit_document_set_enable_search_highlighting  (GEDIT_DOCUMENT (l->data),
-							 		enable);
+									enable);
 
 			l = l->next;
 		}
